==> trilinos_10.0.4.dfsg.orig.tar.gz: trilinos-10.0.4.dfsg.orig/packages/teuchos/src/Teuchos_TableColumn.cpp <==
// @HEADER
// ***********************************************************************
// 
//                    Teuchos: Common Tools Package
//                 Copyright (2004) Sandia Corporation
// 
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Michael A. Heroux (maherou@sandia.gov) 
// 
// ***********************************************************************
// @HEADER

#include "Teuchos_TableColumn.hpp"

using namespace Teuchos;


TableColumn::TableColumn(const Array<std::string>& vals)
  : data_(vals.size())
{
  for (unsigned int i=0; i<vals.size(); i++)
    {
      data_[i] = rcp(new StringEntry(vals[i]));
    }
}


TableColumn::TableColumn(const Array<double>& vals,
                         int precision)
  : data_(vals.size())
{
  for (unsigned int i=0; i<vals.size(); i++)
    {
      data_[i] = rcp(new DoubleEntry(vals[i], precision));
    }
}


TableColumn::TableColumn(const Array<double>& first, 
                         const Array<double>& second,
                         int precision,
                         bool spaceBeforeParentheses)
  : data_(first.size())
{
  for (unsigned int i=0; i<first.size(); i++)
    {
      RCP<DoubleEntry> x1 = rcp(new DoubleEntry(first[i], precision));
      RCP<DoubleEntry> x2 = rcp(new DoubleEntry(second[i], precision));
      data_[i] 
        = rcp(new CompoundEntryWithParentheses(x1, x2,
                                               spaceBeforeParentheses));
    }
}

void TableColumn::addEntry(const RCP<TableEntry>& entry_in)
{
  data_.append(entry_in);
}

==> trilinos_10.4.0.dfsg.orig.tar.gz: trilinos-10.4.0.dfsg.orig/packages/teuchos/src/Teuchos_TableColumn.cpp <==
// @HEADER
// ***********************************************************************
// 
//                    Teuchos: Common Tools Package
//                 Copyright (2004) Sandia Corporation
// 
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Michael A. Heroux (maherou@sandia.gov) 
// 
// ***********************************************************************
// @HEADER

#include "Teuchos_TableColumn.hpp"

using namespace Teuchos;


TableColumn::TableColumn(const Array<std::string>& vals)
  : data_(vals.size())
{
  for (Array<std::string>::size_type i=0; i<vals.size(); i++)
    {
      data_[i] = rcp(new StringEntry(vals[i]));
    }
}


TableColumn::TableColumn(const Array<double>& vals,
                         int precision)
  : data_(vals.size())
{
  for (Array<double>::size_type i=0; i<vals.size(); i++)
    {
      data_[i] = rcp(new DoubleEntry(vals[i], precision));
    }
}


TableColumn::TableColumn(const Array<double>& first, 
                         const Array<double>& second,
                         int precision,
                         bool spaceBeforeParentheses)
  : data_(first.size())
{
  for (Array<double>::size_type i=0; i<first.size(); i++)
    {
      RCP<DoubleEntry> x1 = rcp(new DoubleEntry(first[i], precision));
      RCP<DoubleEntry> x2 = rcp(new DoubleEntry(second[i], precision));
      data_[i] 
        = rcp(new CompoundEntryWithParentheses(x1, x2,
                                               spaceBeforeParentheses));
    }
}

void TableColumn::addEntry(const RCP<TableEntry>& entry_in)
{
  data_.append(entry_in);
}
